@@ -2,22 +2,22 @@
 #include <string.h>
 #include <gst/gst.h>
 
-void
-eof (GstElement * src)
+void 
+eof (GstElement *src) 
 {
   g_print ("have eos, quitting\n");
   exit (0);
 }
 
-gboolean
-idle_func (gpointer data)
+gboolean 
+idle_func (gpointer data) 
 {
   gst_bin_iterate (GST_BIN (data));
   return TRUE;
 }
 
-void
-new_pad_created (GstElement * parse, GstPad * pad, GstElement * pipeline)
+void 
+new_pad_created (GstElement *parse, GstPad *pad, GstElement *pipeline) 
 {
   GstElement *decode_video = NULL;
   GstElement *decode_audio, *play, *color, *show;
@@ -25,7 +25,7 @@ new_pad_created (GstElement * parse, GstPad * pad, GstElement * pipeline)
   GstElement *audio_thread, *video_thread;
 
   g_print ("***** a new pad %s was created\n", gst_pad_get_name (pad));
-
+  
   gst_element_set_state (GST_ELEMENT (pipeline), GST_STATE_PAUSED);
 
   /* link to audio pad */
@@ -45,12 +45,13 @@ new_pad_created (GstElement * parse, GstPad * pad, GstElement * pipeline)
     audio_queue = gst_element_factory_make ("queue", "audio_queue");
     g_return_if_fail (audio_queue != NULL);
 
-    gst_bin_add_many (GST_BIN (audio_thread),
-        audio_queue, decode_audio, play, NULL);
+    gst_bin_add_many (GST_BIN (audio_thread), 
+                      audio_queue, decode_audio, play, NULL);
 
     /* set up pad links */
     gst_element_add_ghost_pad (audio_thread,
-        gst_element_get_pad (audio_queue, "sink"), "sink");
+                               gst_element_get_pad (audio_queue, "sink"),
+                               "sink");
     gst_element_link (audio_queue, decode_audio);
     gst_element_link (decode_audio, play);
 
@@ -62,7 +63,8 @@ new_pad_created (GstElement * parse, GstPad * pad, GstElement * pipeline)
     g_print ("setting to READY state\n");
     gst_element_set_state (GST_ELEMENT (audio_thread), GST_STATE_READY);
 
-  } else if (strncmp (gst_pad_get_name (pad), "video_", 6) == 0) {
+  } 
+  else if (strncmp (gst_pad_get_name (pad), "video_", 6) == 0) {
 
     /* construct internal pipeline elements */
     decode_video = gst_element_factory_make ("mpeg2dec", "decode_video");
@@ -71,7 +73,7 @@ new_pad_created (GstElement * parse, GstPad * pad, GstElement * pipeline)
     color = gst_element_factory_make ("colorspace", "color");
     g_return_if_fail (color != NULL);
 
-
+   
     show = gst_element_factory_make ("xvideosink", "show");
     g_return_if_fail (show != NULL);
 
@@ -82,12 +84,13 @@ new_pad_created (GstElement * parse, GstPad * pad, GstElement * pipeline)
     /* create the thread and pack stuff into it */
     video_thread = gst_thread_new ("video_thread");
     g_return_if_fail (video_thread != NULL);
-    gst_bin_add_many (GST_BIN (video_thread), video_queue,
-        decode_video, color, show, NULL);
+    gst_bin_add_many (GST_BIN (video_thread), video_queue, 
+                      decode_video, color, show, NULL);
 
     /* set up pad links */
     gst_element_add_ghost_pad (video_thread,
-        gst_element_get_pad (video_queue, "sink"), "sink");
+                               gst_element_get_pad (video_queue, "sink"),
+                               "sink");
     gst_element_link (video_queue, decode_video);
     gst_element_link_many (decode_video, color, show, NULL);
 
@@ -102,8 +105,8 @@ new_pad_created (GstElement * parse, GstPad * pad, GstElement * pipeline)
   gst_element_set_state (GST_ELEMENT (pipeline), GST_STATE_PLAYING);
 }
 
-int
-main (int argc, char *argv[])
+int 
+main (int argc, char *argv[]) 
 {
   GstElement *pipeline, *src, *demux;
 
@@ -114,7 +117,7 @@ main (int argc, char *argv[])
 
   src = gst_element_factory_make ("filesrc", "src");
   g_return_val_if_fail (src != NULL, -1);
-  if (argc < 2)
+  if (argc < 2) 
     g_error ("Please specify a video file to play !");
 
   g_object_set (G_OBJECT (src), "location", argv[1], NULL);
@@ -125,9 +128,10 @@ main (int argc, char *argv[])
   gst_bin_add_many (GST_BIN (pipeline), src, demux, NULL);
 
   g_signal_connect (G_OBJECT (demux), "new_pad",
-      G_CALLBACK (new_pad_created), pipeline);
+                     G_CALLBACK (new_pad_created), pipeline);
 
-  g_signal_connect (G_OBJECT (src), "eos", G_CALLBACK (eof), NULL);
+  g_signal_connect (G_OBJECT (src), "eos",
+                     G_CALLBACK (eof), NULL);
 
   gst_element_link (src, demux);
 
@@ -139,5 +143,4 @@ main (int argc, char *argv[])
 
   return 0;
 }
-
 /* example-end dynamic.c */
