@@ -173,16 +173,16 @@ gst_spider_identity_chain (GstPad * pad, GstBuffer * buf)
 {
   GstSpiderIdentity *ident;
 
-  /*g_print ("chaining on pad %s:%s with buffer %p\n", GST_DEBUG_PAD_NAME (pad), buf); */
-
   g_return_if_fail (pad != NULL);
   g_return_if_fail (GST_IS_PAD (pad));
+
   if (buf == NULL)
     return;
 
   ident = GST_SPIDER_IDENTITY (gst_pad_get_parent (pad));
 
   if (GST_IS_EVENT (buf)) {
+    GST_DEBUG_OBJECT (ident, "spider identity received event %p", buf);
     /* start hack for current event stuff here */
     /* check for unlinked elements and send them the EOS event, too */
     if (GST_EVENT_TYPE (GST_EVENT (buf)) == GST_EVENT_EOS) {
@@ -194,23 +194,31 @@ gst_spider_identity_chain (GstPad * pad, GstBuffer * buf)
 
         list = g_list_next (list);
         if (conn->current != (GstElement *) conn->src) {
-          GST_DEBUG ("sending EOS to unconnected element %s from %s",
-              GST_ELEMENT_NAME (conn->src), GST_ELEMENT_NAME (ident));
-          gst_pad_push (conn->src->src,
-              GST_DATA (GST_BUFFER (gst_event_new (GST_EVENT_EOS))));
+          GstEvent *event;
+
+          event = gst_event_new (GST_EVENT_EOS);
+          GST_DEBUG_OBJECT (ident,
+              "sending EOS event %p to unconnected element %s from %s",
+              event, GST_ELEMENT_NAME (conn->src), GST_ELEMENT_NAME (ident));
+          gst_pad_push (conn->src->src, GST_DATA (event));
           gst_element_set_eos (GST_ELEMENT (conn->src));
         }
       }
     }
     /* end hack for current event stuff here */
+    GST_DEBUG_OBJECT (ident,
+        "calling default handler for event %p on pad %s:%s",
+        buf, GST_DEBUG_PAD_NAME (pad));
 
     gst_pad_event_default (pad, GST_EVENT (buf));
     return;
   }
 
   if ((ident->src != NULL) && (GST_PAD_PEER (ident->src) != NULL)) {
-    /* g_print("pushing buffer %p (refcount %d - buffersize %d) to pad %s:%s\n", buf, GST_BUFFER_REFCOUNT (buf), GST_BUFFER_SIZE (buf), GST_DEBUG_PAD_NAME (ident->src)); */
-    GST_LOG ("push %p %" G_GINT64_FORMAT, buf, GST_BUFFER_OFFSET (buf));
+    GST_LOG_OBJECT (ident, "pushing buffer %p "
+        "(refcount %d, size %u, offset %" G_GINT64_FORMAT ") ",
+        buf, GST_BUFFER_REFCOUNT_VALUE (buf),
+        GST_BUFFER_SIZE (buf), GST_BUFFER_OFFSET (buf));
     gst_pad_push (ident->src, GST_DATA (buf));
   } else if (GST_IS_BUFFER (buf)) {
     gst_buffer_unref (buf);
@@ -249,14 +257,15 @@ gst_spider_identity_link (GstPad * pad, const GstCaps * caps)
       GST_SPIDER_IDENTITY (gst_pad_get_parent (pad));
   GstPad *otherpad;
 
-  if (pad == spider_identity->src)
+  if (pad == spider_identity->src) {
     otherpad = spider_identity->sink;
-  else
+    if (GST_PAD_PEER (otherpad) == NULL)
+      return GST_PAD_LINK_DELAYED;
+  } else {
     otherpad = spider_identity->src;
+  }
 
   g_return_val_if_fail (otherpad != NULL, GST_PAD_LINK_REFUSED);
-  if (GST_PAD_PEER (otherpad) == NULL)
-    return GST_PAD_LINK_DELAYED;
 
   return gst_pad_try_set_caps (otherpad, caps);
 }
@@ -310,7 +319,9 @@ gst_spider_identity_request_new_pad (GstElement * element,
         break;
       /* sink */
       GST_DEBUG ("element %s requests new sink pad", GST_ELEMENT_NAME (ident));
-      ident->sink = gst_pad_new ("sink", GST_PAD_SINK);
+      ident->sink =
+          gst_pad_new_from_template (gst_static_pad_template_get
+          (&spider_sink_factory), "sink");
       gst_element_add_pad (GST_ELEMENT (ident), ident->sink);
       gst_pad_set_link_function (ident->sink,
           GST_DEBUG_FUNCPTR (gst_spider_identity_link));
@@ -322,7 +333,9 @@ gst_spider_identity_request_new_pad (GstElement * element,
       if (ident->src != NULL)
         break;
       GST_DEBUG ("element %s requests new src pad", GST_ELEMENT_NAME (ident));
-      ident->src = gst_pad_new ("src", GST_PAD_SRC);
+      ident->src =
+          gst_pad_new_from_template (gst_static_pad_template_get
+          (&spider_src_factory), "src");
       gst_element_add_pad (GST_ELEMENT (ident), ident->src);
       gst_pad_set_link_function (ident->src,
           GST_DEBUG_FUNCPTR (gst_spider_identity_link));
