@@ -65,12 +65,14 @@ struct _GstFileSrc {
   off_t curoffset;			/* current offset in file*/
   off_t block_size;			/* bytes per read */
   gboolean touch;			/* whether to touch every page */
-  gboolean using_mmap;
+  gboolean using_mmap;                  /* whether we opened it with mmap */
+  gboolean is_regular;                  /* whether it's (symlink to)
+                                           a regular file */
 
   GstBuffer *mapbuf;
   size_t mapsize;
 
-  gboolean seek_happened;
+  gint need_discont;
   gboolean need_flush;
 };
 
