@@ -363,19 +363,21 @@ gst_init_check_with_popt_table (int *argc, char **argv[],
   if (gst_debug_env)
     parse_debug_list (gst_debug_env);
 
-  while ((nextopt = poptGetNextOpt (context)) > 0) {
-    /* we only check for failures here, actual work is done in callbacks */
-    if (_gst_initialization_failure)
+  /* Scan until we reach the end (-1), ignoring errors */
+  while ((nextopt = poptGetNextOpt (context)) != -1) {
+
+    /* If an error occurred and it's not an missing options, throw an error
+     * We don't want to show the "unknown option" message, since it'll
+     * might interfere with the applications own command line parsing
+     */
+    if (nextopt < 0 && nextopt != POPT_ERROR_BADOPT) {
+      g_print ("Error on option %s: %s.\nRun '%s --help' "
+          "to see a full list of available command line options.\n",
+          poptBadOption (context, 0), poptStrerror (nextopt), (*argv)[0]);
+
+      poptFreeContext (context);
       return FALSE;
-  }
-
-  if (nextopt != -1) {
-    g_print ("Error on option %s: %s.\nRun '%s --help' "
-        "to see a full list of available command line options.\n",
-        poptBadOption (context, 0), poptStrerror (nextopt), (*argv)[0]);
-
-    poptFreeContext (context);
-    return FALSE;
+    }
   }
 
   *argc = poptStrippedArgv (context, *argc, *argv);
@@ -407,17 +409,24 @@ load_plugin_func (gpointer data, gpointer user_data)
 {
   GstPlugin *plugin;
   const gchar *filename;
+  GError *err = NULL;
 
   filename = (const gchar *) data;
 
-  plugin = gst_plugin_load_file (filename, NULL);
+  plugin = gst_plugin_load_file (filename, &err);
 
   if (plugin) {
     GST_INFO ("Loaded plugin: \"%s\"", filename);
 
     gst_registry_pool_add_plugin (plugin);
   } else {
-    GST_WARNING ("Failed to load plugin: \"%s\"", filename);
+    if (err) {
+      /* Report error to user, and free error */
+      GST_ERROR ("Failed to load plugin: %s\n", err->message);
+      g_error_free (err);
+    } else {
+      GST_WARNING ("Failed to load plugin: \"%s\"", filename);
+    }
   }
 
   g_free (data);
@@ -518,14 +527,14 @@ static gboolean
 gst_register_core_elements (GstPlugin * plugin)
 {
   /* register some standard builtin types */
-  g_assert (gst_element_register (plugin, "bin", GST_RANK_PRIMARY,
-          GST_TYPE_BIN));
-  g_assert (gst_element_register (plugin, "pipeline", GST_RANK_PRIMARY,
-          GST_TYPE_PIPELINE));
-  g_assert (gst_element_register (plugin, "thread", GST_RANK_PRIMARY,
-          GST_TYPE_THREAD));
-  g_assert (gst_element_register (plugin, "queue", GST_RANK_PRIMARY,
-          GST_TYPE_QUEUE));
+  if (!gst_element_register (plugin, "bin", GST_RANK_PRIMARY,
+          GST_TYPE_BIN) ||
+      !gst_element_register (plugin, "pipeline", GST_RANK_PRIMARY,
+          GST_TYPE_PIPELINE) ||
+      !gst_element_register (plugin, "thread", GST_RANK_PRIMARY,
+          GST_TYPE_THREAD) ||
+      !gst_element_register (plugin, "queue", GST_RANK_NONE, GST_TYPE_QUEUE))
+    g_assert_not_reached ();
 
   return TRUE;
 }
@@ -621,6 +630,7 @@ init_post (void)
     gst_registry_pool_add (_global_registry, 100);
     gst_registry_pool_add (_user_registry, 50);
   } else {
+
     gst_registry_pool_add (_global_registry, 100);
   }
 
