@@ -27,7 +27,6 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <gst/gstatomic.h>
-#include <gst/gstlog.h>
 #include <gst/gstconfig.h>
 
 G_BEGIN_DECLS
@@ -51,12 +50,14 @@ typedef enum {
   GST_LEVEL_COUNT
 } GstDebugLevel;
 
-/* we can now override this to be more general in maintainer builds or cvs checkouts */
+/* we can now override this to be more general in maintainer builds
+ * or cvs checkouts */
 #ifndef GST_LEVEL_DEFAULT
 #define GST_LEVEL_DEFAULT GST_LEVEL_NONE
 #endif
 
-/* defines for format (colors etc) - don't change them around, it uses terminal layout 
+/* defines for format (colors etc)
+ * don't change them around, it uses terminal layout
  * Terminal color strings:
  * 00=none 01=bold 04=underscore 05=blink 07=reverse 08=concealed
  * Text color codes:
@@ -104,7 +105,7 @@ struct _GstDebugCategory {
 
 /********** some convenience macros for debugging **********/
 
-/* This is needed in printf's if a char* might be NULL. Solaris crashes then */
+/* This is needed in printf's if a char* might be NULL. Solaris crashes then. */
 #define GST_STR_NULL(str) ((str) ? (str) : "(NULL)")
 
 /* easier debugging for pad names */
@@ -113,8 +114,7 @@ struct _GstDebugCategory {
   GST_STR_NULL (GST_OBJECT_NAME (GST_OBJECT_PARENT(pad))) : \
   "''", GST_OBJECT_NAME (pad)
 
-/* You might want to define GST_FUNCTION in apps' configure script */
-
+/* You might want to define GST_FUNCTION in apps' configure script. */
 #ifndef GST_FUNCTION
 #if defined (__GNUC__)
 #  define GST_FUNCTION     ((const char*) (__PRETTY_FUNCTION__))
@@ -133,54 +133,42 @@ typedef void (*GstLogFunction)	(GstDebugCategory *	category,
 				 const gchar *		function,
 				 gint			line,
 				 GObject *		object,
-				 GstDebugMessage *    	message,
+				 GstDebugMessage *	message,
 				 gpointer		data);
 
-/* Disable this subsystem if no varargs macro can be found. 
-   Use a trick so the core builds the functions nonetheless if it wasn't
-   explicitly disabled. */
-#if !defined(G_HAVE_ISO_VARARGS) && !defined(G_HAVE_GNUC_VARARGS)
-#define __GST_DISABLE_GST_DEBUG
-#endif
-#ifdef GST_DISABLE_GST_DEBUG
-#ifndef __GST_DISABLE_GST_DEBUG
-#define __GST_DISABLE_GST_DEBUG
-#endif
-#endif
-
-#ifndef __GST_DISABLE_GST_DEBUG
+#ifndef GST_DISABLE_GST_DEBUG
 
 void		_gst_debug_init			(void);
 
 /* note we can't use G_GNUC_PRINTF (7, 8) because gcc chokes on %P, which
  * we use for GST_PTR_FORMAT. */
-void		gst_debug_log			(GstDebugCategory *	category,
-						 GstDebugLevel		level,
-						 const gchar *		file,
-						 const gchar *		function,
-						 gint			line,
-						 GObject *		object,
-						 const gchar *		format,
-						 ...) G_GNUC_NO_INSTRUMENT;
-void		gst_debug_log_valist  		(GstDebugCategory *	category,
-						 GstDebugLevel		level,
-						 const gchar *		file,
-						 const gchar *		function,
-						 gint			line,
-						 GObject *		object,
-						 const gchar *		format,
-						 va_list		args) G_GNUC_NO_INSTRUMENT;
+void		gst_debug_log		(GstDebugCategory *	category,
+					 GstDebugLevel		level,
+					 const gchar *		file,
+					 const gchar *		function,
+					 gint			line,
+					 GObject *		object,
+					 const gchar *		format,
+					 ...) G_GNUC_NO_INSTRUMENT;
+void		gst_debug_log_valist	(GstDebugCategory *	category,
+					 GstDebugLevel		level,
+					 const gchar *		file,
+					 const gchar *		function,
+					 gint			line,
+					 GObject *		object,
+					 const gchar *		format,
+					 va_list		args) G_GNUC_NO_INSTRUMENT;
 
-const gchar *	gst_debug_message_get		(GstDebugMessage *	message);
+const gchar *	gst_debug_message_get	(GstDebugMessage *	message);
 
-void		gst_debug_log_default		(GstDebugCategory *	category,
-						 GstDebugLevel		level,
-						 const gchar *		file,
-						 const gchar *		function,
-						 gint			line,
-						 GObject *		object,
-						 GstDebugMessage *    	message,
-						 gpointer		unused) G_GNUC_NO_INSTRUMENT;
+void		gst_debug_log_default	(GstDebugCategory *	category,
+					 GstDebugLevel		level,
+					 const gchar *		file,
+					 const gchar *		function,
+					 gint			line,
+					 GObject *		object,
+					 GstDebugMessage *	message,
+					 gpointer		unused) G_GNUC_NO_INSTRUMENT;
 
 G_CONST_RETURN gchar *
 		gst_debug_level_get_name	(GstDebugLevel		level);
@@ -227,9 +215,9 @@ void		gst_debug_unset_threshold_for_name (const gchar *	name);
  */
 #define GST_DEBUG_CATEGORY_STATIC(cat) static GstDebugCategory *cat = NULL
 /* do not use this function, use the macros below */
-GstDebugCategory *_gst_debug_category_new	(gchar *		name,
-						 guint			color,
-						 gchar *		description);
+GstDebugCategory *_gst_debug_category_new	(gchar *	name,
+						 guint		color,
+						 gchar *	description);
 /**
  * GST_DEBUG_CATEGORY_INIT:
  * @cat: the category to initialize.
@@ -265,44 +253,70 @@ GstDebugCategory *_gst_debug_category_new	(gchar *		name,
  * </para>
  * </note>
  */
-#define GST_DEBUG_CATEGORY_INIT(cat,name,color,description) G_STMT_START{	\
-  if (cat == NULL)								\
-    cat = _gst_debug_category_new (name,color,description);			\
+#define GST_DEBUG_CATEGORY_INIT(cat,name,color,description) G_STMT_START{\
+  if (cat == NULL)							\
+    cat = _gst_debug_category_new (name,color,description);		\
 }G_STMT_END
 
-void		gst_debug_category_free		(GstDebugCategory *	category);
-void		gst_debug_category_set_threshold (GstDebugCategory *	category,
-						 GstDebugLevel		level);
-void		gst_debug_category_reset_threshold (GstDebugCategory *	category);
-GstDebugLevel	gst_debug_category_get_threshold (GstDebugCategory *	category);
+void	gst_debug_category_free		(GstDebugCategory *	category);
+void	gst_debug_category_set_threshold (GstDebugCategory *	category,
+					 GstDebugLevel		level);
+void	gst_debug_category_reset_threshold(GstDebugCategory *	category);
+GstDebugLevel
+	gst_debug_category_get_threshold (GstDebugCategory *	category);
 G_CONST_RETURN gchar *
-		gst_debug_category_get_name	(GstDebugCategory *	category);
-guint		gst_debug_category_get_color	(GstDebugCategory *	category);
+	gst_debug_category_get_name	(GstDebugCategory *	category);
+guint	gst_debug_category_get_color	(GstDebugCategory *	category);
 G_CONST_RETURN gchar *
-		gst_debug_category_get_description (GstDebugCategory *	category);
-GSList *	gst_debug_get_all_categories	(void);
+	gst_debug_category_get_description (GstDebugCategory *	category);
+GSList *
+        gst_debug_get_all_categories	(void);
 
-gchar *		gst_debug_construct_term_color	(guint colorinfo);
+gchar *	gst_debug_construct_term_color	(guint colorinfo);
 
 
-extern GstDebugCategory *	GST_CAT_DEFAULT;
+GST_EXPORT GstDebugCategory *	GST_CAT_DEFAULT;
 /* this symbol may not be used */
 extern gboolean			__gst_debug_enabled;
+
 #ifdef G_HAVE_ISO_VARARGS
-#define GST_CAT_LEVEL_LOG(cat,level,object,...) G_STMT_START{			\
-  if (__gst_debug_enabled) {				\
-    gst_debug_log ((cat), (level), __FILE__, GST_FUNCTION, __LINE__, (GObject *) (object), __VA_ARGS__); \
-  }										\
+#define GST_CAT_LEVEL_LOG(cat,level,object,...) G_STMT_START{		\
+  if (__gst_debug_enabled) {						\
+    gst_debug_log ((cat), (level), __FILE__, GST_FUNCTION, __LINE__,	\
+        (GObject *) (object), __VA_ARGS__);				\
+  }									\
 }G_STMT_END
 #else /* G_HAVE_GNUC_VARARGS */
-#define GST_CAT_LEVEL_LOG(cat,level,object,args...) G_STMT_START{			\
-  if (__gst_debug_enabled) {				\
-    gst_debug_log ((cat), (level), __FILE__, GST_FUNCTION, __LINE__, (GObject *) (object), ##args ); \
-  }										\
+#ifdef G_HAVE_GNUC_VARARGS
+#define GST_CAT_LEVEL_LOG(cat,level,object,args...) G_STMT_START{	\
+  if (__gst_debug_enabled) {						\
+    gst_debug_log ((cat), (level), __FILE__, GST_FUNCTION, __LINE__,	\
+        (GObject *) (object), ##args );					\
+  }									\
 }G_STMT_END
-#endif /* G_HAVE_ISO_VARARGS */
+#else /* no variadic macros, use inline */
+static inline void
+GST_CAT_LEVEL_LOG_valist (GstDebugCategory * cat,
+    GstDebugLevel level, gpointer object, const char *format, va_list varargs)
+{
+  gst_debug_log_valist (cat, level, "", "", 0, (GObject *) object, format,
+      varargs);
+}
 
-#ifndef GST_DEBUG_ENABLE_DEPRECATED
+static inline void
+GST_CAT_LEVEL_LOG (GstDebugCategory * cat, GstDebugLevel level,
+    gpointer object, const char *format, ...)
+{
+  if (__gst_debug_enabled) {
+    va_list varargs;
+
+    va_start (varargs, format);
+    GST_CAT_LEVEL_LOG_valist (cat, level, object, format, varargs);
+    va_end (varargs);
+  }
+}
+#endif
+#endif /* G_HAVE_ISO_VARARGS */
 
 #ifdef G_HAVE_ISO_VARARGS
 
@@ -330,7 +344,8 @@ extern gboolean			__gst_debug_enabled;
 #define GST_DEBUG(...)			GST_CAT_LEVEL_LOG (GST_CAT_DEFAULT, GST_LEVEL_DEBUG,   NULL, __VA_ARGS__)
 #define GST_LOG(...)			GST_CAT_LEVEL_LOG (GST_CAT_DEFAULT, GST_LEVEL_LOG,     NULL, __VA_ARGS__)
 
-#else /* G_HAVE_GNUC_VARARGS */
+#else
+#ifdef G_HAVE_GNUC_VARARGS
 
 #define GST_CAT_ERROR_OBJECT(cat,obj,args...)	GST_CAT_LEVEL_LOG (cat, GST_LEVEL_ERROR,   obj,  ##args )
 #define GST_CAT_WARNING_OBJECT(cat,obj,args...)	GST_CAT_LEVEL_LOG (cat, GST_LEVEL_WARNING, obj,  ##args )
@@ -356,50 +371,240 @@ extern gboolean			__gst_debug_enabled;
 #define GST_DEBUG(args...)		GST_CAT_LEVEL_LOG (GST_CAT_DEFAULT, GST_LEVEL_DEBUG,   NULL, ##args )
 #define GST_LOG(args...)		GST_CAT_LEVEL_LOG (GST_CAT_DEFAULT, GST_LEVEL_LOG,     NULL, ##args )
 
-#endif /* G_HAVE_ISO_VARARGS */
+#else
+/* no variadic macros, use inline */
+static inline void
+GST_CAT_ERROR_OBJECT (GstDebugCategory * cat, gpointer obj, const char *format,
+    ...)
+{
+  va_list varargs;
 
-#else /* GST_DEBUG_ENABLE_DEPRECATED */
-/* This is a workaround so the old debugging stuff of GStreamer 0.6 works.
-   This is undocumented and will go when 0.8 comes out. */
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (cat, GST_LEVEL_ERROR, obj, format, varargs);
+  va_end (varargs);
+}
 
-#ifdef G_HAVE_ISO_VARARGS
-#  define GST_INFO(cat,...)			GST_CAT_LEVEL_LOG (GST_CAT_DEFAULT, GST_LEVEL_INFO,    NULL, __VA_ARGS__)
-#  define GST_DEBUG(cat,...)			GST_CAT_LEVEL_LOG (GST_CAT_DEFAULT, GST_LEVEL_DEBUG,   NULL, __VA_ARGS__)
-#  define GST_INFO_ELEMENT(cat,obj,...)		GST_CAT_LEVEL_LOG (GST_CAT_DEFAULT, GST_LEVEL_INFO,    obj, __VA_ARGS__)
-#  define GST_DEBUG_ELEMENT(cat,obj,...)	GST_CAT_LEVEL_LOG (GST_CAT_DEFAULT, GST_LEVEL_DEBUG,   obj, __VA_ARGS__)
-#  define GST_DEBUG_ENTER(...)			GST_DEBUG ("entering: " __VA_ARGS__ )
-#  define GST_DEBUG_LEAVE(...)			GST_DEBUG ("leaving: "  __VA_ARGS__ )
-#  define GST_INFO_ENTER(...)			GST_INFO ("entering: " __VA_ARGS__ )
-#  define GST_INFO_LEAVE(...)			GST_INFO ("leaving: "  __VA_ARGS__ )
-#else /* G_HAVE_GNUC_VARARGS */
-#  define GST_INFO(cat,args...)			GST_CAT_LEVEL_LOG (GST_CAT_DEFAULT, GST_LEVEL_INFO,    NULL, ##args )
-#  define GST_DEBUG(cat,args...)		GST_CAT_LEVEL_LOG (GST_CAT_DEFAULT, GST_LEVEL_DEBUG,   NULL, ##args )
-#  define GST_INFO_ELEMENT(cat,obj,args...)	GST_CAT_LEVEL_LOG (GST_CAT_DEFAULT, GST_LEVEL_INFO,    obj, ##args )
-#  define GST_DEBUG_ELEMENT(cat,obj,args...)	GST_CAT_LEVEL_LOG (GST_CAT_DEFAULT, GST_LEVEL_DEBUG,   obj, ##args )
-#  define GST_DEBUG_ENTER(args...)		GST_DEBUG ("entering: " ##args )
-#  define GST_DEBUG_LEAVE(args...)		GST_DEBUG ("leaving: "  ##args )
-#  define GST_INFO_ENTER(args...)		GST_INFO ("entering: " ##args )
-#  define GST_INFO_LEAVE(args...)		GST_INFO ("leaving: "  ##args )
-#endif /* G_HAVE_ISO_VARARGS */
+static inline void
+GST_CAT_WARNING_OBJECT (GstDebugCategory * cat, gpointer obj,
+    const char *format, ...)
+{
+  va_list varargs;
 
-#endif /* !GST_DEBUG_ENABLE_DEPRECATED */
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (cat, GST_LEVEL_WARNING, obj, format, varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_CAT_INFO_OBJECT (GstDebugCategory * cat, gpointer obj, const char *format,
+    ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (cat, GST_LEVEL_INFO, obj, format, varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_CAT_DEBUG_OBJECT (GstDebugCategory * cat, gpointer obj, const char *format,
+    ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (cat, GST_LEVEL_DEBUG, obj, format, varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_CAT_LOG_OBJECT (GstDebugCategory * cat, gpointer obj, const char *format,
+    ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (cat, GST_LEVEL_LOG, obj, format, varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_CAT_ERROR (GstDebugCategory * cat, const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (cat, GST_LEVEL_ERROR, NULL, format, varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_CAT_WARNING (GstDebugCategory * cat, const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (cat, GST_LEVEL_WARNING, NULL, format, varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_CAT_INFO (GstDebugCategory * cat, const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (cat, GST_LEVEL_INFO, NULL, format, varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_CAT_DEBUG (GstDebugCategory * cat, const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (cat, GST_LEVEL_DEBUG, NULL, format, varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_CAT_LOG (GstDebugCategory * cat, const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (cat, GST_LEVEL_LOG, NULL, format, varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_ERROR_OBJECT (gpointer obj, const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (GST_CAT_DEFAULT, GST_LEVEL_ERROR, obj, format,
+      varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_WARNING_OBJECT (gpointer obj, const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (GST_CAT_DEFAULT, GST_LEVEL_WARNING, obj, format,
+      varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_INFO_OBJECT (gpointer obj, const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (GST_CAT_DEFAULT, GST_LEVEL_INFO, obj, format,
+      varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_DEBUG_OBJECT (gpointer obj, const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (GST_CAT_DEFAULT, GST_LEVEL_DEBUG, obj, format,
+      varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_LOG_OBJECT (gpointer obj, const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (GST_CAT_DEFAULT, GST_LEVEL_LOG, obj, format,
+      varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_ERROR (const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (GST_CAT_DEFAULT, GST_LEVEL_ERROR, NULL, format,
+      varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_WARNING (const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (GST_CAT_DEFAULT, GST_LEVEL_WARNING, NULL, format,
+      varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_INFO (const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (GST_CAT_DEFAULT, GST_LEVEL_INFO, NULL, format,
+      varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_DEBUG (const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (GST_CAT_DEFAULT, GST_LEVEL_DEBUG, NULL, format,
+      varargs);
+  va_end (varargs);
+}
+
+static inline void
+GST_LOG (const char *format, ...)
+{
+  va_list varargs;
+
+  va_start (varargs, format);
+  GST_CAT_LEVEL_LOG_valist (GST_CAT_DEFAULT, GST_LEVEL_LOG, NULL,
+      format, varargs);
+  va_end (varargs);
+}
+#endif
+#endif
 
 
 /********** function pointer stuff **********/
-void* 		_gst_debug_register_funcptr	(void *			ptr,
-						 gchar *		ptrname);
-G_CONST_RETURN gchar*
-		_gst_debug_nameof_funcptr 	(void *			ptr);
+void *	_gst_debug_register_funcptr	(void *			ptr,
+					 gchar *		ptrname);
+G_CONST_RETURN gchar *
+	_gst_debug_nameof_funcptr	(void *			ptr);
 
 #define GST_DEBUG_FUNCPTR(ptr) (_gst_debug_register_funcptr((void *)(ptr), #ptr) , ptr)
 #define GST_DEBUG_FUNCPTR_NAME(ptr) _gst_debug_nameof_funcptr((void *)ptr)
 
 #else /* GST_DISABLE_GST_DEBUG */
 
-#ifdef __GNUC__
+#if defined(__GNUC__) && __GNUC__ >= 3
 #  pragma GCC poison gst_debug_log
 #  pragma GCC poison gst_debug_log_valist
-#  pragma GCC poison gst_debug_log_default
 #  pragma GCC poison _gst_debug_category_new
 #endif
 
@@ -427,7 +632,11 @@ G_CONST_RETURN gchar*
 
 #define GST_DEBUG_CATEGORY(var)				/* NOP */
 #define GST_DEBUG_CATEGORY_EXTERN(var)			/* NOP */
+#if !defined(G_HAVE_GNUC_VARARGS) && !defined(G_HAVE_ISO_VARARGS)
+#define GST_DEBUG_CATEGORY_STATIC(var)			static GstDebugCategory *var = NULL
+#else
 #define GST_DEBUG_CATEGORY_STATIC(var)			/* NOP */
+#endif
 #define GST_DEBUG_CATEGORY_INIT(var,name,color,desc)	/* NOP */
 #define gst_debug_category_free(category)		/* NOP */
 #define gst_debug_category_set_threshold(category,level) /* NOP */
@@ -467,16 +676,8 @@ G_CONST_RETURN gchar*
 #define GST_DEBUG(...)					/* NOP */
 #define GST_LOG(...)					/* NOP */
 
-#ifdef GST_DEBUG_ENABLE_DEPRECATED
-#define GST_INFO_ELEMENT(cat,obj,...) /* NOP */
-#define GST_DEBUG_ELEMENT(cat,obj,...) /* NOP */
-#define GST_DEBUG_ENTER(...) /* NOP */
-#define GST_DEBUG_LEAVE(...) /* NOP */
-#define GST_INFO_ENTER(...) /* NOP */
-#define GST_INFO_LEAVE(...) /* NOP */
-#endif /* GST_DEBUG_ENABLE_DEPRECATED */
-
-#else /* !G_HAVE_ISO_VARARGS */
+#else
+#ifdef G_HAVE_GNUC_VARARGS
 
 #define GST_CAT_LEVEL_LOG(cat,level,args...)		/* NOP */
 
@@ -504,16 +705,119 @@ G_CONST_RETURN gchar*
 #define GST_DEBUG(args...)				/* NOP */
 #define GST_LOG(args...)				/* NOP */
 
-#ifdef GST_DEBUG_ENABLE_DEPRECATED
-#define GST_INFO_ELEMENT(cat,obj,args...) /* NOP */
-#define GST_DEBUG_ELEMENT(cat,obj,args...) /* NOP */
-#define GST_DEBUG_ENTER(args...) /* NOP */
-#define GST_DEBUG_LEAVE(args...) /* NOP */
-#define GST_INFO_ENTER(args...) /* NOP */
-#define GST_INFO_LEAVE(args...) /* NOP */
-#endif /* GST_DEBUG_ENABLE_DEPRECATED */
+#else
+static inline void
+GST_CAT_LEVEL_LOG_valist (GstDebugCategory * cat,
+    GstDebugLevel level, gpointer object, const char *format, va_list varargs)
+{
+}
 
-#endif /* G_HAVE_ISO_VARARGS */
+static inline void
+GST_CAT_ERROR_OBJECT (GstDebugCategory * cat, gpointer obj, const char *format,
+    ...)
+{
+}
+
+static inline void
+GST_CAT_WARNING_OBJECT (GstDebugCategory * cat, gpointer obj,
+    const char *format, ...)
+{
+}
+
+static inline void
+GST_CAT_INFO_OBJECT (GstDebugCategory * cat, gpointer obj, const char *format,
+    ...)
+{
+}
+
+static inline void
+GST_CAT_DEBUG_OBJECT (GstDebugCategory * cat, gpointer obj, const char *format,
+    ...)
+{
+}
+
+static inline void
+GST_CAT_LOG_OBJECT (GstDebugCategory * cat, gpointer obj, const char *format,
+    ...)
+{
+}
+
+static inline void
+GST_CAT_ERROR (GstDebugCategory * cat, const char *format, ...)
+{
+}
+
+static inline void
+GST_CAT_WARNING (GstDebugCategory * cat, const char *format, ...)
+{
+}
+
+static inline void
+GST_CAT_INFO (GstDebugCategory * cat, const char *format, ...)
+{
+}
+
+static inline void
+GST_CAT_DEBUG (GstDebugCategory * cat, const char *format, ...)
+{
+}
+
+static inline void
+GST_CAT_LOG (GstDebugCategory * cat, const char *format, ...)
+{
+}
+
+static inline void
+GST_ERROR_OBJECT (gpointer obj, const char *format, ...)
+{
+}
+
+static inline void
+GST_WARNING_OBJECT (gpointer obj, const char *format, ...)
+{
+}
+
+static inline void
+GST_INFO_OBJECT (gpointer obj, const char *format, ...)
+{
+}
+
+static inline void
+GST_DEBUG_OBJECT (gpointer obj, const char *format, ...)
+{
+}
+
+static inline void
+GST_LOG_OBJECT (gpointer obj, const char *format, ...)
+{
+}
+
+static inline void
+GST_ERROR (const char *format, ...)
+{
+}
+
+static inline void
+GST_WARNING (const char *format, ...)
+{
+}
+
+static inline void
+GST_INFO (const char *format, ...)
+{
+}
+
+static inline void
+GST_DEBUG (const char *format, ...)
+{
+}
+
+static inline void
+GST_LOG (const char *format, ...)
+{
+}
+#endif
+#endif
 
 #define GST_DEBUG_FUNCPTR(ptr) (ptr)
 #define GST_DEBUG_FUNCPTR_NAME(ptr) (g_strdup_printf ("%p", ptr))
@@ -522,6 +826,15 @@ G_CONST_RETURN gchar*
 
 void gst_debug_print_stack_trace (void);
 
+/* timestamp debugging macros */
+/* FIXME 0.9: move into the correct header (gstclock.h) */
+#define GST_TIME_FORMAT "u:%02u:%02u.%09u"
+#define GST_TIME_ARGS(t) \
+	(guint) ((t) / (GST_SECOND * 60 * 60)), \
+	(guint) (((t) / (GST_SECOND * 60)) % 60), \
+	(guint) (((t) / GST_SECOND) % 60), \
+	(guint) ((t) % GST_SECOND)
+
 G_END_DECLS
 
 #endif /* __GSTINFO_H__ */
