@@ -32,6 +32,7 @@
 #include <unistd.h>
 #endif
 #include <signal.h>
+#include <errno.h>
 
 #include "gst_private.h"
 
@@ -324,7 +325,8 @@ gst_plugin_check_file (const gchar * filename, GError ** error)
   if (stat (filename, &file_status)) {
     g_set_error (error,
         GST_PLUGIN_ERROR,
-        GST_PLUGIN_ERROR_MODULE, "Problem opening file %s\n", filename);
+        GST_PLUGIN_ERROR_MODULE, "Problem accessing file %s: %s\n", filename,
+        strerror (errno));
     return FALSE;
   }
 
@@ -348,6 +350,7 @@ gst_plugin_check_file (const gchar * filename, GError ** error)
     return FALSE;
   }
   /* it's a plugin */
+  GST_INFO ("looks like a gst plugin \"%s\"", filename);
   g_module_close (module);
   return TRUE;
 }
@@ -790,6 +793,9 @@ gst_plugin_add_feature (GstPlugin * plugin, GstPluginFeature * feature)
 {
   GstPluginFeature *oldfeature;
 
+  /* FIXME 0.9: get reference counting somewhat right in here,
+   * GstPluginFeatures should probably be GstObjects that are sinked when
+   * adding them to a plugin */
   g_return_if_fail (plugin != NULL);
   g_return_if_fail (GST_IS_PLUGIN_FEATURE (feature));
   g_return_if_fail (feature != NULL);
@@ -797,7 +803,15 @@ gst_plugin_add_feature (GstPlugin * plugin, GstPluginFeature * feature)
   oldfeature = gst_plugin_find_feature (plugin,
       GST_PLUGIN_FEATURE_NAME (feature), G_OBJECT_TYPE (feature));
 
-  if (!oldfeature) {
+  if (oldfeature == feature) {
+    GST_WARNING ("feature %s has already been added",
+        GST_PLUGIN_FEATURE_NAME (feature));
+    /* g_object_unref (feature); */
+  } else if (oldfeature) {
+    GST_WARNING ("feature %s already present in plugin",
+        GST_PLUGIN_FEATURE_NAME (feature));
+    /* g_object_unref (feature); */
+  } else {
     feature->manager = plugin;
     plugin->features = g_list_prepend (plugin->features, feature);
     plugin->numfeatures++;
