@@ -20,6 +20,7 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
+#include <math.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
@@ -52,21 +53,21 @@ struct _GstValueSubtractInfo
   GstValueSubtractFunc func;
 };
 
-GType gst_type_fourcc;
 GType gst_type_fourcc;
 GType gst_type_int_range;
 GType gst_type_double_range;
 GType gst_type_list;
 GType gst_type_fixed_list;
+GType gst_type_fraction;
 
 static GArray *gst_value_table;
 static GArray *gst_value_union_funcs;
 static GArray *gst_value_intersect_funcs;
 static GArray *gst_value_subtract_funcs;
 
-/********/
-/* list */
-/********/
+/********
+ * list *
+ ********/
 
 /* two helper functions to serialize/stringify any type of list
  * regular lists are done with { }, fixed lists with < >
@@ -399,8 +400,9 @@ gst_value_deserialize_fixed_list (GValue * dest, const char *s)
   return FALSE;
 }
 
-/*************************************/
-/* fourcc */
+/**********
+ * fourcc *
+ **********/
 
 static void
 gst_value_init_fourcc (GValue * value)
@@ -530,8 +532,9 @@ gst_value_deserialize_fourcc (GValue * dest, const char *s)
   return ret;
 }
 
-/*************************************/
-/* int range */
+/*************
+ * int range *
+ *************/
 
 static void
 gst_value_init_int_range (GValue * value)
@@ -590,6 +593,7 @@ void
 gst_value_set_int_range (GValue * value, int start, int end)
 {
   g_return_if_fail (GST_VALUE_HOLDS_INT_RANGE (value));
+  g_return_if_fail (start < end);
 
   value->data[0].v_int = start;
   value->data[1].v_int = end;
@@ -601,7 +605,7 @@ gst_value_set_int_range (GValue * value, int start, int end)
  *
  * Gets the minimum of the range specified by @value.
  *
- * Returns: the minumum of the range
+ * Returns: the minimum of the range
  */
 int
 gst_value_get_int_range_min (const GValue * value)
@@ -658,8 +662,9 @@ gst_value_deserialize_int_range (GValue * dest, const char *s)
   return FALSE;
 }
 
-/*************************************/
-/* double range */
+/****************
+ * double range *
+ ****************/
 
 static void
 gst_value_init_double_range (GValue * value)
@@ -794,8 +799,9 @@ gst_value_deserialize_double_range (GValue * dest, const char *s)
   return FALSE;
 }
 
-/*************************************/
-/* GstCaps */
+/***********
+ * GstCaps *
+ ***********/
 
 /**
  * gst_value_set_caps:
@@ -829,8 +835,9 @@ gst_value_get_caps (const GValue * value)
   return (GstCaps *) g_value_get_boxed (value);
 }
 
-/*************************************/
-/* GstBuffer */
+/*************
+ * GstBuffer *
+ *************/
 
 static int
 gst_value_compare_buffer (const GValue * value1, const GValue * value2)
@@ -863,7 +870,7 @@ gst_value_serialize_buffer (const GValue * value)
   data = GST_BUFFER_DATA (buffer);
   size = GST_BUFFER_SIZE (buffer);
 
-  string = malloc (size * 2 + 1);
+  string = g_malloc (size * 2 + 1);
   for (i = 0; i < size; i++) {
     sprintf (string + i * 2, "%02x", data[i]);
   }
@@ -888,7 +895,7 @@ gst_value_deserialize_buffer (GValue * dest, const char *s)
   buffer = gst_buffer_new_and_alloc (len / 2);
   data = GST_BUFFER_DATA (buffer);
   for (i = 0; i < len / 2; i++) {
-    if (!isxdigit (s[i * 2]) || !isxdigit (s[i * 2 + 1])) {
+    if (!isxdigit ((int) s[i * 2]) || !isxdigit ((int) s[i * 2 + 1])) {
       ret = FALSE;
       break;
     }
@@ -909,8 +916,9 @@ gst_value_deserialize_buffer (GValue * dest, const char *s)
 }
 
 
-/*************************************/
-/* boolean */
+/***********
+ * boolean *
+ ***********/
 
 static int
 gst_value_compare_boolean (const GValue * value1, const GValue * value2)
@@ -949,8 +957,9 @@ gst_value_deserialize_boolean (GValue * dest, const char *s)
   return ret;
 }
 
-/*************************************/
-/* ints */
+/*******
+ * int *
+ *******/
 
 static int
 gst_strtoll (const char *s, char **end, int base)
@@ -1101,8 +1110,9 @@ CREATE_USERIALIZATION (uint, UINT)
 CREATE_USERIALIZATION (uint64, UINT64)
 CREATE_USERIALIZATION (ulong, ULONG)
 
-/*************************************/
-/* double */
+/**********
+ * double *
+ **********/
      static int
          gst_value_compare_double (const GValue * value1, const GValue * value2)
 {
@@ -1149,8 +1159,9 @@ gst_value_deserialize_double (GValue * dest, const char *s)
   return ret;
 }
 
-/*************************************/
-/* float */
+/*********
+ * float *
+ *********/
 
 static int
 gst_value_compare_float (const GValue * value1, const GValue * value2)
@@ -1200,8 +1211,9 @@ gst_value_deserialize_float (GValue * dest, const char *s)
   return ret;
 }
 
-/*************************************/
-/* string */
+/**********
+ * string *
+ **********/
 
 static int
 gst_value_compare_string (const GValue * value1, const GValue * value2)
@@ -1243,7 +1255,7 @@ gst_string_wrap (const char *s)
   }
 
   if (!wrap)
-    return strdup (s);
+    return g_strdup (s);
 
   e = d = g_malloc (len + 3);
 
@@ -1282,20 +1294,23 @@ gst_value_deserialize_string (GValue * dest, const char *s)
   return TRUE;
 }
 
-/*************************************/
-/* enums */
+/********
+ * enum *
+ ********/
 
 static int
 gst_value_compare_enum (const GValue * value1, const GValue * value2)
 {
   GEnumValue *en1, *en2;
-  GEnumClass *klass1 = (GEnumClass *) g_type_class_peek (G_VALUE_TYPE (value1));
-  GEnumClass *klass2 = (GEnumClass *) g_type_class_peek (G_VALUE_TYPE (value2));
+  GEnumClass *klass1 = (GEnumClass *) g_type_class_ref (G_VALUE_TYPE (value1));
+  GEnumClass *klass2 = (GEnumClass *) g_type_class_ref (G_VALUE_TYPE (value2));
 
   g_return_val_if_fail (klass1, GST_VALUE_UNORDERED);
   g_return_val_if_fail (klass2, GST_VALUE_UNORDERED);
   en1 = g_enum_get_value (klass1, g_value_get_enum (value1));
   en2 = g_enum_get_value (klass2, g_value_get_enum (value2));
+  g_type_class_unref (klass1);
+  g_type_class_unref (klass2);
   g_return_val_if_fail (en1, GST_VALUE_UNORDERED);
   g_return_val_if_fail (en2, GST_VALUE_UNORDERED);
   if (en1->value < en2->value)
@@ -1310,10 +1325,11 @@ static char *
 gst_value_serialize_enum (const GValue * value)
 {
   GEnumValue *en;
-  GEnumClass *klass = (GEnumClass *) g_type_class_peek (G_VALUE_TYPE (value));
+  GEnumClass *klass = (GEnumClass *) g_type_class_ref (G_VALUE_TYPE (value));
 
   g_return_val_if_fail (klass, NULL);
   en = g_enum_get_value (klass, g_value_get_enum (value));
+  g_type_class_unref (klass);
   g_return_val_if_fail (en, NULL);
   return g_strdup (en->value_name);
 }
@@ -1323,7 +1339,7 @@ gst_value_deserialize_enum (GValue * dest, const char *s)
 {
   GEnumValue *en;
   gchar *endptr = NULL;
-  GEnumClass *klass = (GEnumClass *) g_type_class_peek (G_VALUE_TYPE (dest));
+  GEnumClass *klass = (GEnumClass *) g_type_class_ref (G_VALUE_TYPE (dest));
 
   g_return_val_if_fail (klass, FALSE);
   if (!(en = g_enum_get_value_by_name (klass, s))) {
@@ -1335,13 +1351,15 @@ gst_value_deserialize_enum (GValue * dest, const char *s)
       }
     }
   }
+  g_type_class_unref (klass);
   g_return_val_if_fail (en, FALSE);
   g_value_set_enum (dest, en->value);
   return TRUE;
 }
 
-/*************************************/
-/* unions */
+/*********
+ * union *
+ *********/
 
 static gboolean
 gst_value_union_int_int_range (GValue * dest, const GValue * src1,
@@ -1383,8 +1401,9 @@ gst_value_union_int_range_int_range (GValue * dest, const GValue * src1,
   return FALSE;
 }
 
-/*************************************/
-/* intersection */
+/****************
+ * intersection *
+ ****************/
 
 static gboolean
 gst_value_intersect_int_int_range (GValue * dest, const GValue * src1,
@@ -1507,8 +1526,35 @@ gst_value_intersect_list (GValue * dest, const GValue * value1,
   return ret;
 }
 
-/*************************************/
-/* subtraction */
+static gboolean
+gst_value_intersect_fixed_list (GValue * dest, const GValue * src1,
+    const GValue * src2)
+{
+  gint size, n;
+  GValue val = { 0 };
+
+  /* only works on similar-sized arrays */
+  size = gst_value_list_get_size (src1);
+  if (size != gst_value_list_get_size (src2))
+    return FALSE;
+  g_value_init (dest, GST_TYPE_FIXED_LIST);
+
+  for (n = 0; n < size; n++) {
+    if (!gst_value_intersect (&val, gst_value_list_get_value (src1, n),
+            gst_value_list_get_value (src2, n))) {
+      g_value_unset (dest);
+      return FALSE;
+    }
+    gst_value_list_append_value (dest, &val);
+    g_value_unset (&val);
+  }
+
+  return TRUE;
+}
+
+/***************
+ * subtraction *
+ ***************/
 
 static gboolean
 gst_value_subtract_int_int_range (GValue * dest, const GValue * minuend,
@@ -1759,7 +1805,9 @@ gst_value_subtract_list (GValue * dest, const GValue * minuend,
 }
 
 
-/*************************************/
+/**************
+ * comparison *
+ **************/
 
 /**
  * gst_value_can_compare:
@@ -1780,7 +1828,7 @@ gst_value_can_compare (const GValue * value1, const GValue * value2)
     return FALSE;
   for (i = 0; i < gst_value_table->len; i++) {
     table = &g_array_index (gst_value_table, GstValueTable, i);
-    if (table->type == G_VALUE_TYPE (value1) && table->compare)
+    if (g_type_is_a (G_VALUE_TYPE (value1), table->type) && table->compare)
       return TRUE;
   }
 
@@ -1803,7 +1851,7 @@ gst_value_can_compare (const GValue * value1, const GValue * value2)
 int
 gst_value_compare (const GValue * value1, const GValue * value2)
 {
-  GstValueTable *table;
+  GstValueTable *table, *best = NULL;
   int i;
 
   if (G_VALUE_TYPE (value1) != G_VALUE_TYPE (value2))
@@ -1811,10 +1859,17 @@ gst_value_compare (const GValue * value1, const GValue * value2)
 
   for (i = 0; i < gst_value_table->len; i++) {
     table = &g_array_index (gst_value_table, GstValueTable, i);
-    if (table->type != G_VALUE_TYPE (value1) || table->compare == NULL)
-      continue;
-
-    return table->compare (value1, value2);
+    if (table->type == G_VALUE_TYPE (value1) && table->compare != NULL) {
+      best = table;
+      break;
+    }
+    if (g_type_is_a (G_VALUE_TYPE (value1), table->type)) {
+      if (!best || g_type_is_a (table->type, best->type))
+        best = table;
+    }
+  }
+  if (best) {
+    return best->compare (value1, value2);
   }
 
   g_critical ("unable to compare values of type %s\n",
@@ -1919,7 +1974,7 @@ gst_value_register_union_func (GType type1, GType type2, GstValueUnionFunc func)
 
 /* intersection */
 
-/*
+/**
  * gst_value_can_intersect:
  * @value1:
  * @value2:
@@ -2128,7 +2183,7 @@ gst_value_register_subtract_func (GType minuend_type, GType subtrahend_type,
   g_array_append_val (gst_value_subtract_funcs, info);
 }
 
-/*
+/**
  * gst_value_register:
  * @table:
  *
@@ -2139,7 +2194,7 @@ gst_value_register (const GstValueTable * table)
   g_array_append_val (gst_value_table, *table);
 }
 
-/*
+/**
  * gst_value_init_and_copy:
  * @dest:
  * @src:
@@ -2152,7 +2207,7 @@ gst_value_init_and_copy (GValue * dest, const GValue * src)
   g_value_copy (src, dest);
 }
 
-/*
+/**
  * gst_value_serialize:
  * @value: a #GValue to serialize
  *
@@ -2198,7 +2253,7 @@ gst_value_serialize (const GValue * value)
   return s;
 }
 
-/*
+/**
  * gst_value_deserialize:
  * @dest: #GValue to fill with contents of deserialization
  * @src: string to deserialize
@@ -2236,11 +2291,16 @@ gst_value_deserialize (GValue * dest, const gchar * src)
   return FALSE;
 }
 
-/*
+/**
  * gst_type_is_fixed:
- * @type:
+ * @type: the #GType to check
  *
- * Returns:
+ * Tests if the given GType, if available in a GstStructure (or any other
+ * container) will contain a "fixed" (which means: one possible value) or
+ * an "unfixed" (which means: multiple possible values, such as data lists
+ * or data ranges) value.
+ *
+ * Returns: true if the type is "fixed".
  */
 gboolean
 gst_type_is_fixed (GType type)
@@ -2254,13 +2314,362 @@ gst_type_is_fixed (GType type)
     return TRUE;
   }
   if (type == GST_TYPE_BUFFER || type == GST_TYPE_FOURCC
-      || type == GST_TYPE_FIXED_LIST) {
+      || type == GST_TYPE_FIXED_LIST || type == GST_TYPE_FRACTION) {
     return TRUE;
   }
 
   return FALSE;
 }
 
+/************
+ * fraction *
+ ************/
+
+/* helper functions */
+
+/* Finds the greatest common divisor.
+ * Returns 1 if none other found.
+ * This is Euclid's algorithm. */
+static gint
+gst_greatest_common_divisor (gint a, gint b)
+{
+  while (b != 0) {
+    int temp = a;
+
+    a = b;
+    b = temp % b;
+  }
+
+  return ABS (a);
+}
+
+static void
+gst_value_init_fraction (GValue * value)
+{
+  value->data[0].v_int = 0;
+  value->data[1].v_int = 1;
+}
+
+static void
+gst_value_copy_fraction (const GValue * src_value, GValue * dest_value)
+{
+  dest_value->data[0].v_int = src_value->data[0].v_int;
+  dest_value->data[1].v_int = src_value->data[1].v_int;
+}
+
+static gchar *
+gst_value_collect_fraction (GValue * value, guint n_collect_values,
+    GTypeCValue * collect_values, guint collect_flags)
+{
+  value->data[0].v_int = collect_values[0].v_int;
+  value->data[1].v_int = collect_values[1].v_int;
+
+  return NULL;
+}
+
+static gchar *
+gst_value_lcopy_fraction (const GValue * value, guint n_collect_values,
+    GTypeCValue * collect_values, guint collect_flags)
+{
+  gint *numerator = collect_values[0].v_pointer;
+  gint *denominator = collect_values[1].v_pointer;
+
+  if (!numerator)
+    return g_strdup_printf ("numerator for `%s' passed as NULL",
+        G_VALUE_TYPE_NAME (value));
+  if (!denominator)
+    return g_strdup_printf ("denominator for `%s' passed as NULL",
+        G_VALUE_TYPE_NAME (value));
+
+  *numerator = value->data[0].v_int;
+  *denominator = value->data[1].v_int;
+
+  return NULL;
+}
+
+/**
+ * gst_value_set_fraction:
+ * @value: a GValue initialized to GST_TYPE_FRACTION
+ * @numerator: the numerator of the fraction
+ * @denominator: the denominator of the fraction
+ *
+ * Sets @value to the fraction specified by @numerator over @denominator.
+ * The fraction gets reduced to the smallest numerator and denominator,
+ * and if necessary the sign is moved to the numerator.
+ */
+void
+gst_value_set_fraction (GValue * value, gint numerator, gint denominator)
+{
+  gint gcd = 0;
+
+  g_return_if_fail (GST_VALUE_HOLDS_FRACTION (value));
+  g_return_if_fail (denominator != 0);
+  g_return_if_fail (denominator >= -G_MAXINT);
+  g_return_if_fail (numerator >= -G_MAXINT);
+
+  /* normalize sign */
+  if (denominator < 0) {
+    numerator = -numerator;
+    denominator = -denominator;
+  }
+
+  /* check for reduction */
+  gcd = gst_greatest_common_divisor (numerator, denominator);
+  if (gcd) {
+    numerator /= gcd;
+    denominator /= gcd;
+  }
+  value->data[0].v_int = numerator;
+  value->data[1].v_int = denominator;
+}
+
+/**
+ * gst_value_get_fraction_numerator:
+ * @value: a GValue initialized to GST_TYPE_FRACTION
+ *
+ * Gets the numerator of the fraction specified by @value.
+ *
+ * Returns: the numerator of the fraction.
+ */
+int
+gst_value_get_fraction_numerator (const GValue * value)
+{
+  g_return_val_if_fail (GST_VALUE_HOLDS_FRACTION (value), 0);
+
+  return value->data[0].v_int;
+}
+
+/**
+ * gst_value_get_fraction_denominator:
+ * @value: a GValue initialized to GST_TYPE_FRACTION
+ *
+ * Gets the denominator of the fraction specified by @value.
+ *
+ * Returns: the denominator of the fraction.
+ */
+int
+gst_value_get_fraction_denominator (const GValue * value)
+{
+  g_return_val_if_fail (GST_VALUE_HOLDS_FRACTION (value), 0);
+
+  return value->data[1].v_int;
+}
+
+/**
+ * gst_value_fraction_multiply:
+ * @product: a GValue initialized to GST_TYPE_FRACTION
+ * @factor1: a GValue initialized to GST_TYPE_FRACTION
+ * @factor2: a GValue initialized to GST_TYPE_FRACTION
+ *
+ * Multiplies the two GValues containing a GstFraction and sets @product
+ * to the product of the two fractions.
+ *
+ * Returns: FALSE in case of an error (like integer overflow), TRUE otherwise.
+ */
+gboolean
+gst_value_fraction_multiply (GValue * product, const GValue * factor1,
+    const GValue * factor2)
+{
+  gint gcd, n1, n2, d1, d2;
+
+  g_return_val_if_fail (GST_VALUE_HOLDS_FRACTION (factor1), FALSE);
+  g_return_val_if_fail (GST_VALUE_HOLDS_FRACTION (factor2), FALSE);
+
+  n1 = factor1->data[0].v_int;
+  n2 = factor2->data[0].v_int;
+  d1 = factor1->data[1].v_int;
+  d2 = factor2->data[1].v_int;
+
+  gcd = gst_greatest_common_divisor (n1, d2);
+  n1 /= gcd;
+  d2 /= gcd;
+  gcd = gst_greatest_common_divisor (n2, d1);
+  n2 /= gcd;
+  d1 /= gcd;
+
+  g_return_val_if_fail (n1 == 0 || G_MAXINT / ABS (n1) >= ABS (n2), FALSE);
+  g_return_val_if_fail (G_MAXINT / ABS (d1) >= ABS (d2), FALSE);
+
+  gst_value_set_fraction (product, n1 * n2, d1 * d2);
+
+  return TRUE;
+}
+
+static char *
+gst_value_serialize_fraction (const GValue * value)
+{
+  gint32 numerator = value->data[0].v_int;
+  gint32 denominator = value->data[1].v_int;
+  gboolean positive = TRUE;
+
+  /* get the sign and make components absolute */
+  if (numerator < 0) {
+    numerator = -numerator;
+    positive = !positive;
+  }
+  if (denominator < 0) {
+    denominator = -denominator;
+    positive = !positive;
+  }
+
+  return g_strdup_printf ("%s%d/%d",
+      positive ? "" : "-", numerator, denominator);
+}
+
+static gboolean
+gst_value_deserialize_fraction (GValue * dest, const char *s)
+{
+  gint num, den;
+  char *div;
+  char *tmp;
+
+  div = strstr (s, "/");
+  if (!div)
+    return FALSE;
+  tmp = g_strndup (s, (size_t) (div - s));
+  num = atoi (tmp);
+  g_free (tmp);
+  den = atoi (div + 1);
+
+  gst_value_set_fraction (dest, num, den);
+
+  return TRUE;
+}
+
+static void
+gst_value_transform_fraction_string (const GValue * src_value,
+    GValue * dest_value)
+{
+  dest_value->data[0].v_pointer = gst_value_serialize_fraction (src_value);
+}
+
+static void
+gst_value_transform_string_fraction (const GValue * src_value,
+    GValue * dest_value)
+{
+  gst_value_deserialize_fraction (dest_value, src_value->data[0].v_pointer);
+}
+
+#define MAX_TERMS       30
+#define MIN_DIVISOR     1.0e-10
+#define MAX_ERROR       1.0e-20
+
+/* use continued fractions to transform a double into a fraction,
+ * see http://mathforum.org/dr.math/faq/faq.fractions.html#decfrac.
+ * This algorithm takes care of overflows.
+ */
+static void
+gst_value_transform_double_fraction (const GValue * src_value,
+    GValue * dest_value)
+{
+  gdouble V, F;                 /* double being converted */
+  gint N, D;                    /* will contain the result */
+  gint A;                       /* current term in continued fraction */
+  gint64 N1, D1;                /* numerator, denominator of last approx */
+  gint64 N2, D2;                /* numerator, denominator of previous approx */
+  gint i;
+  gboolean negative = FALSE;
+
+  /* initialize fraction being converted */
+  F = src_value->data[0].v_double;
+  if (F < 0.0) {
+    F = -F;
+    negative = TRUE;
+  }
+
+  V = F;
+  /* initialize fractions with 1/0, 0/1 */
+  N1 = 1;
+  D1 = 0;
+  N2 = 0;
+  D2 = 1;
+  N = 1;
+  D = 1;
+
+  for (i = 0; i < MAX_TERMS; i++) {
+    /* get next term */
+    A = floor (F);
+    /* get new divisor */
+    F = F - A;
+
+    /* calculate new fraction in temp */
+    N2 = N1 * A + N2;
+    D2 = D1 * A + D2;
+
+    /* guard against overflow */
+    if (N2 > G_MAXINT || D2 > G_MAXINT) {
+      break;
+    }
+
+    N = N2;
+    D = D2;
+
+    /* save last two fractions */
+    N2 = N1;
+    D2 = D1;
+    N1 = N;
+    D1 = D;
+
+    /* quit if dividing by zero or close enough to target */
+    if (F < MIN_DIVISOR || fabs (V - ((gdouble) N) / D) < MAX_ERROR) {
+      break;
+    }
+
+    /* Take reciprocal */
+    F = 1 / F;
+  }
+  /* fix for overflow */
+  if (D == 0) {
+    N = G_MAXINT;
+    D = 1;
+  }
+  /* fix for negative */
+  if (negative)
+    N = -N;
+
+  /* will also simplify */
+  gst_value_set_fraction (dest_value, N, D);
+}
+
+static void
+gst_value_transform_fraction_double (const GValue * src_value,
+    GValue * dest_value)
+{
+  dest_value->data[0].v_double = ((double) src_value->data[0].v_int) /
+      ((double) src_value->data[1].v_int);
+}
+
+static int
+gst_value_compare_fraction (const GValue * value1, const GValue * value2)
+{
+  /* FIXME: maybe we should make this more mathematically correct instead
+   * of approximating with gdoubles */
+
+  gint n1, n2;
+  gint d1, d2;
+
+  gdouble new_num_1;
+  gdouble new_num_2;
+
+  n1 = value1->data[0].v_int;
+  n2 = value2->data[0].v_int;
+  d1 = value1->data[1].v_int;
+  d2 = value2->data[1].v_int;
+
+  /* fractions are reduced when set, so we can quickly see if they're equal */
+  if (n1 == n2 && d1 == d2)
+    return GST_VALUE_EQUAL;
+
+  new_num_1 = n1 * d2;
+  new_num_2 = n2 * d1;
+  if (new_num_1 < new_num_2)
+    return GST_VALUE_LESS_THAN;
+  if (new_num_1 > new_num_2)
+    return GST_VALUE_GREATER_THAN;
+  g_assert_not_reached ();
+  return GST_VALUE_UNORDERED;
+}
+
 void
 _gst_value_initialize (void)
 {
@@ -2446,6 +2855,32 @@ _gst_value_initialize (void)
     gst_value.type = GST_TYPE_BUFFER;
     gst_value_register (&gst_value);
   }
+  {
+    static const GTypeValueTable value_table = {
+      gst_value_init_fraction,
+      NULL,
+      gst_value_copy_fraction,
+      NULL,
+      "ii",
+      gst_value_collect_fraction,
+      "pp",
+      gst_value_lcopy_fraction
+    };
+    static GstValueTable gst_value = {
+      0,
+      gst_value_compare_fraction,
+      gst_value_serialize_fraction,
+      gst_value_deserialize_fraction,
+    };
+
+    info.value_table = &value_table;
+    gst_type_fraction =
+        g_type_register_fundamental (g_type_fundamental_next (), "GstFraction",
+        &info, &finfo, 0);
+    gst_value.type = gst_type_fraction;
+    gst_value_register (&gst_value);
+  }
+
 
   REGISTER_SERIALIZATION (G_TYPE_DOUBLE, double);
   REGISTER_SERIALIZATION (G_TYPE_FLOAT, float);
@@ -2473,6 +2908,14 @@ _gst_value_initialize (void)
       gst_value_transform_list_string);
   g_value_register_transform_func (GST_TYPE_FIXED_LIST, G_TYPE_STRING,
       gst_value_transform_fixed_list_string);
+  g_value_register_transform_func (GST_TYPE_FRACTION, G_TYPE_STRING,
+      gst_value_transform_fraction_string);
+  g_value_register_transform_func (G_TYPE_STRING, GST_TYPE_FRACTION,
+      gst_value_transform_string_fraction);
+  g_value_register_transform_func (GST_TYPE_FRACTION, G_TYPE_DOUBLE,
+      gst_value_transform_fraction_double);
+  g_value_register_transform_func (G_TYPE_DOUBLE, GST_TYPE_FRACTION,
+      gst_value_transform_double_fraction);
 
   gst_value_register_intersect_func (G_TYPE_INT, GST_TYPE_INT_RANGE,
       gst_value_intersect_int_int_range);
@@ -2482,6 +2925,8 @@ _gst_value_initialize (void)
       gst_value_intersect_double_double_range);
   gst_value_register_intersect_func (GST_TYPE_DOUBLE_RANGE,
       GST_TYPE_DOUBLE_RANGE, gst_value_intersect_double_range_double_range);
+  gst_value_register_intersect_func (GST_TYPE_FIXED_LIST,
+      GST_TYPE_FIXED_LIST, gst_value_intersect_fixed_list);
 
   gst_value_register_subtract_func (G_TYPE_INT, GST_TYPE_INT_RANGE,
       gst_value_subtract_int_int_range);
