@@ -59,7 +59,8 @@ guint32			gst_bytestream_read		(GstByteStream *bs, GstBuffer** buf, guint32 len)
 guint64			gst_bytestream_tell		(GstByteStream *bs);
 guint64			gst_bytestream_length		(GstByteStream *bs);
 gboolean		gst_bytestream_size_hint	(GstByteStream *bs, guint32 size);
-gboolean		gst_bytestream_seek		(GstByteStream *bs, gint64 offset, GstSeekType type);
+gboolean		gst_bytestream_seek		(GstByteStream *bs, gint64 offset, GstSeekType method);
+
 guint32			gst_bytestream_peek		(GstByteStream *bs, GstBuffer** buf, guint32 len);
 guint32			gst_bytestream_peek_bytes	(GstByteStream *bs, guint8** data, guint32 len);
 gboolean		gst_bytestream_flush		(GstByteStream *bs, guint32 len);
