@@ -32,6 +32,7 @@
 #include <gst/gstmarshal.h>
 
 GST_DEBUG_CATEGORY_EXTERN (_gst_control_debug);
+#define GST_CAT_DEFAULT _gst_control_debug
 
 static void gst_dparam_class_init (GstDParamClass * klass);
 static void gst_dparam_init (GstDParam * dparam);
@@ -138,6 +139,8 @@ gst_dparam_init (GstDParam * dparam)
  * gst_dparam_new:
  * @type: the type that this dparam will store
  *
+ * Create a new dynamic parameter controller.
+ *
  * Returns: a new instance of GstDParam
  */
 GstDParam *
@@ -242,6 +245,17 @@ gst_dparam_set_property (GObject * object, guint prop_id, const GValue * value,
   GST_DPARAM_UNLOCK (dparam);
 }
 
+/**
+ * gst_dparam_do_update_default:
+ * @dparam: 
+ * @timestamp:
+ * @value:
+ * @update_info:
+ *
+ * Default implementation for changing a dynamic parameter.
+ * Subclasses might overwrite the behaviour of this.
+ *
+ */
 void
 gst_dparam_do_update_default (GstDParam * dparam, gint64 timestamp,
     GValue * value, GstDParamUpdateInfo update_info)
@@ -296,7 +310,12 @@ gst_dparam_dispose (GObject * object)
  * gst_dparam_attach
  * @dparam: GstDParam instance
  * @manager: the GstDParamManager that this dparam belongs to
+ * @param_spec: the specification for the parameter
+ * @unit_name: the name of the unit
  *
+ * Adding the parameter controller to the manager using the
+ * supplied specs and unit.
+ * See also gst_dpman_attach_dparam().
  */
 void
 gst_dparam_attach (GstDParam * dparam, GstDParamManager * manager,
@@ -325,8 +344,8 @@ gst_dparam_attach (GstDParam * dparam, GstDParamManager * manager,
 /**
  * gst_dparam_detach
  * @dparam: GstDParam instance
- * @manager: the GstDParamManager that this dparam belongs to
  *
+ * Removes a previousely added parameter controller.
  */
 void
 gst_dparam_detach (GstDParam * dparam)
