@@ -25,6 +25,7 @@
 #include <gst/gstinfo.h>
 
 GST_DEBUG_CATEGORY_EXTERN (_gst_control_debug);
+#define GST_CAT_DEFAULT _gst_control_debug
 
 static GHashTable *_element_registry = NULL;
 static gboolean _gst_dpman_init_done = FALSE;
@@ -42,7 +43,7 @@ static GstDParamWrapper *gst_dpman_new_wrapper (GstDParamManager * dpman,
     GParamSpec * param_spec, gchar * unit_name,
     GstDPMUpdateMethod update_method);
 static GstDParamWrapper *gst_dpman_get_wrapper (GstDParamManager * dpman,
-    gchar * dparam_name);
+    const gchar * dparam_name);
 static void gst_dpman_state_change (GstElement * element, gint old_state,
     gint new_state, GstDParamManager * dpman);
 static gboolean gst_dpman_preprocess_synchronous (GstDParamManager * dpman,
@@ -92,6 +93,7 @@ gst_dpman_get_type (void)
       0,
       (GInstanceInitFunc) gst_dpman_init,
     };
+
     dpman_type =
         g_type_register_static (GST_TYPE_OBJECT, "GstDParamManager",
         &dpman_info, 0);
@@ -136,7 +138,6 @@ gst_dpman_init (GstDParamManager * dpman)
 {
   GST_DPMAN_DPARAMS (dpman) = g_hash_table_new (g_str_hash, g_str_equal);
   GST_DPMAN_DPARAMS_LIST (dpman) = NULL;
-  GST_DPMAN_NAME (dpman) = NULL;
   GST_DPMAN_PARENT (dpman) = NULL;
   GST_DPMAN_MODE_NAME (dpman) = NULL;
   GST_DPMAN_MODE (dpman) = NULL;
@@ -145,10 +146,12 @@ gst_dpman_init (GstDParamManager * dpman)
 
 /**
  * gst_dpman_new:
- * @name: name of the GstDParamManager instance
- * @parent: element which created this instance
+ * @name: name of the new #GstDParamManager instance to create
+ * @parent: #GstElement which creates this instance
  *
- * Returns: a new instance of GstDParamManager
+ * Creates a new instance of a dynamic parameter manager.
+ *
+ * Returns: a new instance of #GstDParamManager.
  */
 GstDParamManager *
 gst_dpman_new (gchar * name, GstElement * parent)
@@ -178,9 +181,14 @@ gst_dpman_dispose (GObject * object)
 /**
  * gst_dpman_add_required_dparam_callback:
  * @dpman: GstDParamManager instance
+ * @param_spec: the spacification of the new dparam
+ * @unit_name: the unit name of the dparam
  * @update_func: callback to update the element with the new value
  * @update_data: will be included in the call to update_func
  *
+ * Add a mandatory dynamic parameter to the manager, where the value can be
+ * updated by calling the supplied callback function.
+ *
  * Returns: true if it was successfully added
  */
 gboolean
@@ -214,8 +222,13 @@ gst_dpman_add_required_dparam_callback (GstDParamManager * dpman,
 /**
  * gst_dpman_add_required_dparam_direct:
  * @dpman: GstDParamManager instance
+ * @param_spec: the spacification of the new dparam
+ * @unit_name: the unit name of the dparam
  * @update_data: pointer to the member to be updated
  *
+ * Add a mandatory dynamic parameter to the manager, where the value can be
+ * updated by directly storing it into the provided memory location.
+ *
  * Returns: true if it was successfully added
  */
 gboolean
@@ -247,9 +260,13 @@ gst_dpman_add_required_dparam_direct (GstDParamManager * dpman,
 /**
  * gst_dpman_add_required_dparam_array:
  * @dpman: GstDParamManager instance
- * @dparam_name: a parameter name unique to this GstDParamManager
+ * @param_spec: the spacification of the new dparam
+ * @unit_name: the unit name of the dparam
  * @update_data: pointer to where the array will be stored
  *
+ * Add a mandatory dynamic parameter to the manager, where the values can be
+ * updated by storing them into the provided memory location.
+ *
  * Returns: true if it was successfully added
  */
 gboolean
@@ -283,9 +300,11 @@ gst_dpman_add_required_dparam_array (GstDParamManager * dpman,
  * @dpman: GstDParamManager instance
  * @dparam_name: the name of an existing parameter
  *
+ * Removes the named dynamic parameter from the manager.
  */
 void
-gst_dpman_remove_required_dparam (GstDParamManager * dpman, gchar * dparam_name)
+gst_dpman_remove_required_dparam (GstDParamManager * dpman,
+    const gchar * dparam_name)
 {
   GstDParamWrapper *dpwrap;
 
@@ -314,10 +333,13 @@ gst_dpman_remove_required_dparam (GstDParamManager * dpman, gchar * dparam_name)
  * @dparam_name: a name previously added with gst_dpman_add_required_dparam
  * @dparam: GstDParam instance to attach
  *
+ * Adding a parameter controller to a dynamic parameter. Whenever the controller
+ * changes, the dynamic parameter of the GstElement will follow.
+ *
  * Returns: true if it was successfully attached
  */
 gboolean
-gst_dpman_attach_dparam (GstDParamManager * dpman, gchar * dparam_name,
+gst_dpman_attach_dparam (GstDParamManager * dpman, const gchar * dparam_name,
     GstDParam * dparam)
 {
   GstDParamWrapper *dpwrap;
@@ -347,9 +369,10 @@ gst_dpman_attach_dparam (GstDParamManager * dpman, gchar * dparam_name,
  * @dpman: GstDParamManager instance
  * @dparam_name: the name of a parameter with a previously attached GstDParam
  *
+ * Removing a parameter controller from a dynamic parameter.
  */
 void
-gst_dpman_detach_dparam (GstDParamManager * dpman, gchar * dparam_name)
+gst_dpman_detach_dparam (GstDParamManager * dpman, const gchar * dparam_name)
 {
   GstDParamWrapper *dpwrap;
 
@@ -358,7 +381,6 @@ gst_dpman_detach_dparam (GstDParamManager * dpman, gchar * dparam_name)
   g_return_if_fail (dparam_name != NULL);
 
   dpwrap = gst_dpman_get_wrapper (dpman, dparam_name);
-
   g_return_if_fail (dpwrap);
 
   gst_dparam_detach (dpwrap->dparam);
@@ -369,20 +391,22 @@ gst_dpman_detach_dparam (GstDParamManager * dpman, gchar * dparam_name)
 /**
  * gst_dpman_get_dparam:
  * @dpman: GstDParamManager instance
- * @name: the name of an existing dparam instance
+ * @dparam_name: the name of an existing dparam instance
+ *
+ * Fetches a dparam object that is registered by manager under the given name.
  *
  * Returns: the dparam with the given name - or NULL otherwise
  */
 GstDParam *
-gst_dpman_get_dparam (GstDParamManager * dpman, gchar * name)
+gst_dpman_get_dparam (GstDParamManager * dpman, const gchar * dparam_name)
 {
   GstDParamWrapper *dpwrap;
 
   g_return_val_if_fail (dpman != NULL, NULL);
   g_return_val_if_fail (GST_IS_DPMAN (dpman), NULL);
-  g_return_val_if_fail (name != NULL, NULL);
+  g_return_val_if_fail (dparam_name != NULL, NULL);
 
-  dpwrap = g_hash_table_lookup (GST_DPMAN_DPARAMS (dpman), name);
+  dpwrap = gst_dpman_get_wrapper (dpman, dparam_name);
   g_return_val_if_fail (dpwrap != NULL, NULL);
 
   return dpwrap->dparam;
@@ -391,25 +415,35 @@ gst_dpman_get_dparam (GstDParamManager * dpman, gchar * name)
 /**
  * gst_dpman_get_dparam_type:
  * @dpman: GstDParamManager instance
- * @name: the name of dparam
+ * @dparam_name: the name of dparam
+ *
+ * Fetches the type of the supplied dynamic parameter.
  *
  * Returns: the type that this dparam requires/uses
  */
 GType
-gst_dpman_get_dparam_type (GstDParamManager * dpman, gchar * name)
+gst_dpman_get_dparam_type (GstDParamManager * dpman, const gchar * dparam_name)
 {
   GstDParamWrapper *dpwrap;
 
   g_return_val_if_fail (dpman != NULL, 0);
   g_return_val_if_fail (GST_IS_DPMAN (dpman), 0);
-  g_return_val_if_fail (name != NULL, 0);
+  g_return_val_if_fail (dparam_name != NULL, 0);
 
-  dpwrap = g_hash_table_lookup (GST_DPMAN_DPARAMS (dpman), name);
+  dpwrap = gst_dpman_get_wrapper (dpman, dparam_name);
   g_return_val_if_fail (dpwrap != NULL, 0);
 
   return G_VALUE_TYPE (dpwrap->value);
 }
 
+/**
+ * gst_dpman_list_dparam_specs:
+ * @dpman: GstDParamManager instance
+ *
+ * Fetches the list of parameter specifications, that this manager maintains.
+ *
+ * Returns: the the parameter specifications as a NULL terminated array
+ */
 GParamSpec **
 gst_dpman_list_dparam_specs (GstDParamManager * dpman)
 {
@@ -433,8 +467,17 @@ gst_dpman_list_dparam_specs (GstDParamManager * dpman)
   return param_specs;
 }
 
+/**
+ * gst_dpman_get_param_spec:
+ * @dpman: GstDParamManager instance
+ * @dparam_name: the name of dparam
+ *
+ * Fetches a single parameter specification by its dparam name.
+ *
+ * Returns: the the parameter specifications for a given name
+ */
 GParamSpec *
-gst_dpman_get_param_spec (GstDParamManager * dpman, gchar * dparam_name)
+gst_dpman_get_param_spec (GstDParamManager * dpman, const gchar * dparam_name)
 {
   GstDParamWrapper *dpwrap;
 
@@ -446,6 +489,14 @@ gst_dpman_get_param_spec (GstDParamManager * dpman, gchar * dparam_name)
   return dpwrap->param_spec;
 }
 
+/**
+ * gst_dpman_set_rate:
+ * @dpman: GstDParamManager instance
+ * @rate: the new the frame/sample rate
+ *
+ * Sets the frame or sampling rate used by the machine.
+ *
+ */
 void
 gst_dpman_set_rate (GstDParamManager * dpman, gint rate)
 {
@@ -462,6 +513,10 @@ gst_dpman_set_rate (GstDParamManager * dpman, gint rate)
  * @setupfunc: the function which initialises the mode when activated
  * @teardownfunc: the function which frees any resources the mode uses
  *
+ * Registers a run-mode for the dparam manager. Each such mode has a defined
+ * run-time behaviour - that is, they differ in the way dynamic parameter
+ * changes are pushed into the underlying GstElements.
+ * 
  */
 void
 gst_dpman_register_mode (GstDParamManagerClass * klass,
@@ -491,6 +546,8 @@ gst_dpman_register_mode (GstDParamManagerClass * klass,
  * @dpman: GstDParamManager instance
  * @modename: the name of the mode to use
  *
+ * Activate one of the registered modes.
+ *
  * Returns: TRUE if the mode was set, FALSE otherwise
  */
 gboolean
@@ -532,6 +589,7 @@ gst_dpman_set_mode (GstDParamManager * dpman, gchar * modename)
  * @dpman: GstDParamManager instance
  * @parent: the element that this GstDParamManager belongs to
  *
+ * Set a GstElement that parameters this manager should handle.
  */
 void
 gst_dpman_set_parent (GstDParamManager * dpman, GstElement * parent)
@@ -551,6 +609,8 @@ gst_dpman_set_parent (GstDParamManager * dpman, GstElement * parent)
  * gst_dpman_get_manager
  * @parent: the element that the desired GstDParamManager belongs to
  *
+ * Fetch the GstElement that parameters are handled by this manager.
+ *
  * Returns: the GstDParamManager which belongs to this element or NULL
  * if it doesn't exist
  */
@@ -577,7 +637,7 @@ gst_dpman_get_manager (GstElement * parent)
  * 
  */
 void
-gst_dpman_bypass_dparam (GstDParamManager * dpman, gchar * dparam_name)
+gst_dpman_bypass_dparam (GstDParamManager * dpman, const gchar * dparam_name)
 {
   GstDParamWrapper *dpwrap;
 
@@ -595,8 +655,10 @@ gst_dpman_bypass_dparam (GstDParamManager * dpman, gchar * dparam_name)
   }
 }
 
+// internal methods
+
 static GstDParamWrapper *
-gst_dpman_get_wrapper (GstDParamManager * dpman, gchar * dparam_name)
+gst_dpman_get_wrapper (GstDParamManager * dpman, const gchar * dparam_name)
 {
   g_return_val_if_fail (dpman != NULL, NULL);
   g_return_val_if_fail (GST_IS_DPMAN (dpman), NULL);
