@@ -1,5 +1,5 @@
 #include "gstmempool.h"
-#include <string.h>		/* memset */
+#include <string.h>             /* memset */
 
 #ifdef __SMP__
 #define POOL_LOCK "lock ; "
@@ -27,7 +27,7 @@
  *
  */
 static gboolean
-populate (GstMemPool *mem_pool) 
+populate (GstMemPool * mem_pool)
 {
   guint8 *area;
   gint i;
@@ -37,10 +37,10 @@ populate (GstMemPool *mem_pool)
 
   area = (guint8 *) g_malloc (mem_pool->area_size);
 
-  for (i=0; i < mem_pool->area_size; i += mem_pool->pool_size) { 
+  for (i = 0; i < mem_pool->area_size; i += mem_pool->pool_size) {
     guint8 *areap = area + i;
 
-    GST_MEM_POOL_AREA (areap) = (GstMemPoolElement *)area;
+    GST_MEM_POOL_AREA (areap) = (GstMemPoolElement *) area;
 
     if (mem_pool->alloc_func) {
       mem_pool->alloc_func (mem_pool, GST_MEM_POOL_DATA (areap));
@@ -53,10 +53,9 @@ populate (GstMemPool *mem_pool)
 }
 
 
-GstMemPool*
-gst_mem_pool_new (gchar* name, gint atom_size, gulong area_size, gint type, 
-		  GstMemPoolAllocFunc alloc_func,
-		  GstMemPoolFreeFunc free_func)
+GstMemPool *
+gst_mem_pool_new (gchar * name, gint atom_size, gulong area_size, gint type,
+    GstMemPoolAllocFunc alloc_func, GstMemPoolFreeFunc free_func)
 {
   GstMemPool *mem_pool;
 
@@ -66,7 +65,7 @@ gst_mem_pool_new (gchar* name, gint atom_size, gulong area_size, gint type,
   mem_pool = g_malloc (sizeof (GstMemPool));
 
   mem_pool->pool_size = atom_size + sizeof (GstMemPoolElement);
-  area_size = (area_size/atom_size) * mem_pool->pool_size;
+  area_size = (area_size / atom_size) * mem_pool->pool_size;
 
   mem_pool->name = g_strdup (name);
   mem_pool->free = NULL;
@@ -93,7 +92,7 @@ free_area (gpointer key, gpointer value, gpointer user_data)
 }
 
 void
-gst_mem_pool_destroy (GstMemPool *mem_pool) 
+gst_mem_pool_destroy (GstMemPool * mem_pool)
 {
   GHashTable *elements = g_hash_table_new (NULL, NULL);
   gpointer data;
@@ -104,10 +103,10 @@ gst_mem_pool_destroy (GstMemPool *mem_pool)
   while (data) {
     GstMemPoolElement *elem = GST_MEM_POOL_LINK (data);
 
-    g_hash_table_insert (elements, GST_MEM_POOL_AREA (elem), NULL); 
-    
+    g_hash_table_insert (elements, GST_MEM_POOL_AREA (elem), NULL);
+
     data = gst_mem_pool_alloc (mem_pool);
-  } 
+  }
   g_hash_table_foreach_remove (elements, free_area, NULL);
 
   g_hash_table_destroy (elements);
@@ -116,28 +115,17 @@ gst_mem_pool_destroy (GstMemPool *mem_pool)
 }
 
 gpointer
-gst_mem_pool_alloc (GstMemPool *mem_pool)
+gst_mem_pool_alloc (GstMemPool * mem_pool)
 {
   volatile GstMemPoolElement *pool = NULL;
-  
+
   g_return_val_if_fail (mem_pool != NULL, NULL);
 
 again:
 #if defined(USE_ASM) && defined(HAVE_CPU_I386)
-  __asm__ __volatile__ ("  testl %%eax, %%eax 		\n\t"
-  			"  jz 20f 			\n"
-			"10:				\t"
-			"  movl (%%eax), %%ebx  	\n\t"
-			"  movl %%edx, %%ecx    	\n\t"
-			"  incl %%ecx 			\n\t"
-			POOL_LOCK "cmpxchg8b %1 	\n\t"
-			"  jz 20f 			\n\t"
-			"  testl %%eax, %%eax 		\n\t"
-			"  jnz 10b 			\n"
-			"20:\t"
-			:"=a" (pool)
-			:"m" (*mem_pool), "a" (mem_pool->free), "d" (mem_pool->cnt)
-			:"ecx", "ebx");
+__asm__ __volatile__ ("  testl %%eax, %%eax 		\n\t" "  jz 20f 			\n" "10:				\t" "  movl (%%eax), %%ebx  	\n\t" "  movl %%edx, %%ecx    	\n\t" "  incl %%ecx 			\n\t" POOL_LOCK "cmpxchg8b %1 	\n\t" "  jz 20f 			\n\t" "  testl %%eax, %%eax 		\n\t" "  jnz 10b 			\n" "20:\t":"=a" (pool)
+:    "m" (*mem_pool), "a" (mem_pool->free), "d" (mem_pool->cnt)
+:    "ecx", "ebx");
 #else
   g_mutex_lock (mem_pool->chunk_lock);
   if (mem_pool->free) {
@@ -151,40 +139,39 @@ again:
     /*g_print ("extending\n"); */
     if (populate (mem_pool))
       goto again;
-    else 
+    else
       return NULL;
   }
   return GST_MEM_POOL_DATA (pool);
 }
 
 gpointer
-gst_mem_pool_alloc0 (GstMemPool *mem_pool)
+gst_mem_pool_alloc0 (GstMemPool * mem_pool)
 {
   gpointer mem = gst_mem_pool_alloc (mem_pool);
 
   if (mem)
     memset (mem, 0, mem_pool->atom_size);
-  
+
   return mem;
 }
 
 void
-gst_mem_pool_free (GstMemPool *mem_pool, gpointer mem)
+gst_mem_pool_free (GstMemPool * mem_pool, gpointer mem)
 {
   GstMemPoolElement *pool;
-  
+
   g_return_if_fail (mem_pool != NULL);
   g_return_if_fail (mem != NULL);
 
   pool = GST_MEM_POOL_LINK (mem);
 
 #if defined(USE_ASM) && defined(HAVE_CPU_I386)
-  __asm__ __volatile__ ( "1:				\t"
-			"  movl %2, (%1) 		\n"
-			POOL_LOCK "cmpxchg %1, %0 	\n\t"
-			"  jnz 1b 			\n\t"
-			:
-			:"m" (*mem_pool), "r" (pool), "a" (mem_pool->free));
+  __asm__ __volatile__ ("1:				\t"
+      "  movl %2, (%1) 		\n"
+      POOL_LOCK "cmpxchg %1, %0 	\n\t"
+      "  jnz 1b 			\n\t"::
+      "m" (*mem_pool), "r" (pool), "a" (mem_pool->free));
 #else
   g_mutex_lock (mem_pool->chunk_lock);
   pool->link = (GstMemPoolElement *) mem_pool->free;
